@@ -11,6 +11,7 @@ from pandas_profiling.model.pandas import (
     describe_numeric_pandas,
     describe_path_pandas,
     describe_supported_pandas,
+    describe_timeseries_pandas,
     describe_url_pandas,
     duplicates_pandas,
     missing_pandas,
@@ -32,6 +33,7 @@ __all__ = [
     "describe_numeric_pandas",
     "describe_path_pandas",
     "describe_supported_pandas",
+    "describe_timeseries_pandas",
     "describe_url_pandas",
     "duplicates_pandas",
     "missing_pandas",
