@@ -7,6 +7,7 @@ from visions import VisionsBaseType, VisionsTypeset
 from pandas_profiling.config import Settings
 from pandas_profiling.model.handler import Handler
 from pandas_profiling.model.summary_algorithms import (
+    describe_boolean_1d,
     describe_categorical_1d,
     describe_counts,
     describe_date_1d,
@@ -58,7 +59,9 @@ class PandasProfilingSummarizer(BaseSummarizer):
             "Categorical": [
                 describe_categorical_1d,
             ],
-            "Boolean": [],
+            "Boolean": [
+                describe_boolean_1d,
+            ],
             "URL": [
                 describe_url_1d,
             ],
